@@ -34,6 +34,9 @@
 #define	RELP_H_INCLUDED
 
 #include <pthread.h>
+#if HAVE_SYS_EPOLL_H
+#	include <sys/epoll.h>
+#endif
 
 #include "librelp.h"
 
@@ -59,19 +62,47 @@ typedef struct relpPermittedPeers_s {
 	char **name;
 } relpPermittedPeers_t;
 
+#if defined(HAVE_EPOLL_CREATE1) || defined(HAVE_EPOLL_CREATE)
+typedef struct epolld_s epolld_t;
+#endif
 /* a linked list entry for the list of relp servers (of this engine) */
 typedef struct relpEngSrvLst_s {
 	struct relpEngSrvLst_s *pPrev;
 	struct relpEngSrvLst_s *pNext;
+#	if defined(HAVE_EPOLL_CREATE1) || defined(HAVE_EPOLL_CREATE)
+	epolld_t **epevts;
+#	endif
 	struct relpSrv_s *pSrv;
 } relpEngSrvLst_t;
 
+#if defined(HAVE_EPOLL_CREATE1) || defined(HAVE_EPOLL_CREATE)
+/* type of object stored in epoll descriptor */
+typedef enum {
+	epolld_lstn,
+	epolld_sess
+} epolld_type_t;
+
+/* an epoll descriptor. contains all information necessary to process
+ * the result of epoll.
+ */
+struct epolld_s {
+	epolld_type_t typ;
+	void *ptr;
+	int sock;
+	struct epoll_event ev;
+};
+#endif
+
 
 /* a linked list entry for the list of relp sessions (of this engine) */
 typedef struct relpEngSessLst_s {
 	struct relpEngSessLst_s *pPrev;
 	struct relpEngSessLst_s *pNext;
 	struct relpSess_s *pSess;
+#	if defined(HAVE_EPOLL_CREATE1) || defined(HAVE_EPOLL_CREATE)
+	enum { epoll_wronly, epoll_rdonly, epoll_rdwr } epollState;
+	epolld_t *epevt;
+#	endif
 } relpEngSessLst_t;
 
 
@@ -93,6 +124,7 @@ struct relpEngine_s {
 		                  unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
 	void (*onAuthErr)(void*pUsr, char *authinfo, char*errmsg, relpRetVal errcode);
 	void (*onErr)(void*pUsr, char *objinfo, char*errmsg, relpRetVal errcode);
+	void (*onGenericErr)(char *objinfo, char*errmsg, relpRetVal errcode);
 	int protocolVersion; /**< version of the relp protocol supported by this engine */
 
 	/* Flags */
@@ -115,6 +147,9 @@ struct relpEngine_s {
 	int lenSessLst;
 	pthread_mutex_t mutSessLst;
 
+#	if defined(HAVE_EPOLL_CREATE1) || defined(HAVE_EPOLL_CREATE)
+	int efd;	/**< file descriptor for epoll */
+#	endif
 	int bStop;	/* set to 1 to stop server after next select */
 	int *bShutdownImmdt; /* if non-NULL provides a kind of "external" */
 		/* bStop functionality. This is in support for rsyslog,
@@ -159,6 +194,7 @@ struct relpEngine_s {
 
 /* some macros to work with librelp error codes */
 #define CHKRet(code) if((iRet = code) != RELP_RET_OK) goto finalize_it
+#define CHKmalloc(r) if((r) == NULL) { iRet = RELP_RET_OUT_OF_MEMORY; goto finalize_it; }
 /* macro below is to be used if we need our own handling, eg for cleanup */
 #define CHKRet_Hdlr(code) if((iRet = code) != RELP_RET_OK)
 /* macro below is used in conjunction with CHKiRet_Hdlr, else use ABORT_FINALIZE */
@@ -184,5 +220,6 @@ static inline int relpEngineShouldStop(relpEngine_t *pThis) {
 
 /* prototypes needed by library itself (rest is in librelp.h) */
 relpRetVal relpEngineDispatchFrame(relpEngine_t *pThis, relpSess_t *pSess, relpFrame_t *pFrame);
+void __attribute__((format(printf, 4, 5))) relpEngineCallOnGenericErr(relpEngine_t *pThis, char *eobj, relpRetVal ecode, char *fmt, ...);
 
 #endif /* #ifndef RELP_H_INCLUDED */
